<instructions>

First, independently design your solution with a focus on clean, maintainable, and efficient code, considering clarity, reusability, performance, testability, and security. Then, analyze and refine your solution step-by-step to ensure that it conforms to coding standards and is easy to collaborate on. Finally, review your solution in the context of real-world scenarios to assess its scalability, maintainability, and adaptability over time.

Write all the code for your project in one file, rather than splitting it into multiple files, and add comments to indicate where each snippet will be located. Only split code into multiple files and write it in a single file if it's absolutely necessary for functionality, such as creating server and client programs that must be inherently separate.

</instructions>
